=====
Usage
=====

Examples

https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/tree/master/examples

YouTube tutorials

https://www.youtube.com/watch?v=MLQecKYQFvg&list=PL9DCOjERDBeGGVBBlaEWMMDoS_06MZcto
